@@ -20,7 +20,7 @@ class ClickLabel : public QLabel
 {
     Q_OBJECT
 public:
-    ClickLabel(QWidget *parent) : QLabel(parent) {};
+    ClickLabel(QWidget *parent) : QLabel(parent) {}
 
 signals:
     void clicked();
@@ -37,11 +37,11 @@ public:
 	     bool nolegend = FALSE);
     ~BarGraph();
 
-    void setColor(int div, QColor color) { colors[div] = color; };
-    QColor color(int div) { return colors[div]; };
+    void setColor(int div, QColor color) { colors[div] = color; }
+    QColor color(int div) { return colors[div]; }
     void setValue(int bar, int div, unsigned long value)
-        { values(bar, div) = value; };
-    void setLabel(int div, const char *name) { names[div] = name; };
+        { values(bar, div) = value; }
+    void setLabel(int div, const char *name) { names[div] = name; }
     void refresh();
     void setOrientation(bool vertical);
 
@@ -61,7 +61,7 @@ private:
 
     // accessors for values
     unsigned long &values(int bar, int div)
-        { return vals[bar * ndivs + div]; };
+        { return vals[bar * ndivs + div]; }
 
     int nbars;			// number of parallel bars
     int ndivs;			// number of divisions of each bar
@@ -75,7 +75,7 @@ private:
 
     static const int label_width = 50;
     static const int label_height = 16;
-    static const int title_width = 28;
+    static const int title_width = 30;
     static const int title_height = 16;
     static const int bar_thickness = 16;
 };
@@ -85,10 +85,10 @@ class CpuLabel : public QFrame
 {
     Q_OBJECT
 public:
-    CpuLabel::CpuLabel(QWidget *parent, int cpus);
+    CpuLabel(QWidget *parent, int cpus);
 
     void setValue(int cpu, int field, unsigned long value)
-        { values(cpu, field) = value; };
+        { values(cpu, field) = value; }
     void setOrientation(bool vertical);
     
 signals:
@@ -101,7 +101,7 @@ protected:
     int ncpus;
     unsigned long *vals;	// array of 4 * ncpus
     // accessor for values
-    unsigned long &values(int cpu, int field) {return vals[cpu * 4 + field];};
+    unsigned long &values(int cpu, int field) {return vals[cpu * 4 + field];}
     bool vert;
 };
 
@@ -132,10 +132,11 @@ private:
     int npoints;		// nr of history points currently remembered
     // history points are stored in fixed point, scaled by history_scale
     static const unsigned history_scale = 256;
+    static const int time_dist = 60; // time between vertical lines (seconds)
     unsigned *history;		// (circular) history buffer
     unsigned peak;		// largest value in history
     int h_index;		// next history index to use
-
+    
     bool dirty;			// history changed since pixmap was drawn
     QPixmap pm;
 };
@@ -146,9 +147,9 @@ class Infobar : public QWidget
 public:
     Infobar(QWidget *parent);
 
-    void refresh(bool step_load);
+    void refresh();
     void update_load();
-    QPixmap *load_icon(int w, int h) { return load_graph->make_icon(w, h); };
+    QPixmap *load_icon(int w, int h) { return load_graph->make_icon(w, h); }
     void configure();
     void configure_geometry();
     bool swaplim_exceeded();
@@ -178,7 +179,6 @@ private:
 
     bool is_vertical;
 
-    void mem_string(int kbytes, char *buf);
     void show_and_hide(bool, QWidget *, QWidget *);
 };
 
