@@ -10,7 +10,7 @@
 #include <qradiobutton.h>
 #include <qlabel.h>
 #include <qbuttongroup.h>
-#include "crossbox.h"
+#include "misc.h"
 
 class Preferences : public QDialog {
     Q_OBJECT
