@@ -23,6 +23,8 @@ public:
     void setRows();
     void set_initial_mode(bool treemode);
     void set_mode(bool treemode);
+    virtual void moveCol(int col, int place);
+    void update_customfield();
 
 public slots:
     void selection_update(const Svec<int> *row);
@@ -45,6 +47,8 @@ protected:
     virtual int parentRow(int row);
     virtual bool lastChild(int row);
 
+    virtual void drawCellContents(int row, int col, int w, int h, QPainter *p);
+	
 private:
     Procview *procview;
     int leftmostchanged;	// leftmost (physical) col whose width changed,
